########################################################################################
# Experiment 3 No evidence for feature overwriting in visual working memory (2013)
# built under R version 2.15.0
# Reinhold Kliegl & Elisabeth Jnger
############################################################################################################
library(reshape)
library(lattice)
library(MASS)
library(ggplot2)  
library(lme4)
library(languageR)	
set.seed(1234321)
library(psy)
library(ltm)

# data path (choose the right path)
setwd("C:/Users/Elisabeth/Desktop/PMR2/Experiment3")

# read in data
Rohdaten<- read.csv("data3.csv", header = TRUE);

# summary data
dim(Rohdaten)
head(Rohdaten)
Rohdaten<-as.data.frame(Rohdaten)
summary(Rohdaten) # Alter 16- 37... mean = 24
#########################################################################################################
## number in each condition?
sum(Rohdaten$Bed==1)
sum(Rohdaten$Bed==2)

sum(Rohdaten$Cue==1)
sum(Rohdaten$Cue==2)
sum(Rohdaten$Cue==3)

sum(Rohdaten$Ort==1)
sum(Rohdaten$Ort==2)
sum(Rohdaten$Ort==3)
sum(Rohdaten$Ort==4)

###########################################################################################################
### how much correct overall?
###########################################################################################################
# Bed = 1 (KG); shape
a<-sum(Rohdaten$korr1[Rohdaten$Bed==1]==1)
b<-sum(Rohdaten$korr1[Rohdaten$Bed==1]==0)
Fo1<-100/ (a+ b) * a

# Bed = 2 (EG); shape
a<-sum(Rohdaten$korr1[Rohdaten$Bed==2]==1)
b<-sum(Rohdaten$korr1[Rohdaten$Bed==2]==0)
Fo2<-100/ (a+ b) * a

# Bed = 3; texture
a<-sum(Rohdaten$korr2[Rohdaten$Bed==1]==1)
b<-sum(Rohdaten$korr2[Rohdaten$Bed==1]==0)
Mu1<-100/ (a+ b) * a

# Bed = 2; texture
a<-sum(Rohdaten$korr2[Rohdaten$Bed==2]==1)
b<-sum(Rohdaten$korr2[Rohdaten$Bed==2]==0)
Mu2<-100/ (a+ b) * a

# Bed = 1; colour
a<-sum(Rohdaten$korr3[Rohdaten$Bed==1]==1)
b<-sum(Rohdaten$korr3[Rohdaten$Bed==1]==0)
Fa1<-100/ (a+ b) * a

# Bed = 2; colour
a<-sum(Rohdaten$korr3[Rohdaten$Bed==2]==1)
b<-sum(Rohdaten$korr3[Rohdaten$Bed==2]==0)
Fa2<-100/ (a+ b) * a

Antworten =  matrix(c(Fo1,Fo2,Mu1,Mu2,Fa1,Fa2),2,3) # data
colnames(Antworten) = c("shape", "texture", "colour")
rownames(Antworten) = c("KG", "EG")
.abscis <- barplot(Antworten, width = 0.5,space=c(0,2), beside=TRUE, col=1:2,ylim=c(0,100),
main="% Correct Answers",
ylab="% Correct",
xlab="Probe Type")
# Legend
legend("topright",legend=c("Control Condition","Experimental Condition"),fill=c(1,2))
mean(c(Fo1,Fo2,Mu1,Mu2,Fa1,Fa2))
c(Fo1,Fo2,Mu1,Mu2,Fa1,Fa2)

################################################################################################################
## Models 
################################################################################################################################

rm(list=ls())
data <- read.csv("data3.csv", header = TRUE);

data$id <- factor(data$Vpn)
#data$sex <- factor(data$Geschlecht)
data$item <- factor(data$Aufgabe)              # item
data$Bedingung <- factor(data$Bed, labels=c("C", "E"))
data$P_Ort <- factor(data$Ort)

data$Cond1[data$Bedingung=="C"]<- 1
data$Cond1[data$Rep1==0 &data$Bedingung=="E"]<- 1
data$Cond1[data$Rep1==1 &data$Bedingung=="E"]<- 2

data$Cond2[data$Bedingung=="C"]<- 1
data$Cond2[data$Rep2==0 &data$Bedingung=="E"]<- 1
data$Cond2[data$Rep2==1 &data$Bedingung=="E"]<- 2

data$Cond3[data$Bedingung=="C"]<- 1
data$Cond3[data$Rep3==0 &data$Bedingung=="E"]<- 1
data$Cond3[data$Rep3==1 &data$Bedingung=="E"]<- 2

table(data$Cond1[data$korr1!=-1], data$Bedingung[data$korr1!=-1])              # check
table(data$Cond2[data$korr2!=-1], data$Bedingung[data$korr2!=-1]) 
table(data$Cond3[data$korr3!=-1], data$Bedingung[data$korr3!=-1]) 

data$cond1 <- factor(paste(data$Bedingung, data$Cond1, sep="_"))
data$cond2 <- factor(paste(data$Bedingung, data$Cond2, sep="_"))
data$cond3 <- factor(paste(data$Bedingung, data$Cond3, sep="_"))

table(data$id, data$cond1)                    # checks
table(data$id, data$cond1, data$P_Ort)        # balanced by position

##########################################################################
# Contrasts
cmat <- matrix(c( 1,  -1,  0,        # C- E non-repeated
                0.5,0.5 , -1), 3, 2) # C- E repeated
 
cmat.inv <- fractions(ginv(t(cmat)))
contrasts(data$cond1) <- cmat.inv
contrasts(data$cond2) <- cmat.inv
contrasts(data$cond3) <- cmat.inv

### GLMM
print(shape <- lmer(korr1 ~ cond1 + (1 | id), family=binomial, data=data[data$korr1!=-1,]), cor=F)
print(texture <- lmer(korr2 ~ cond2 + (1 | id), family=binomial, data=data[data$korr2!=-1,]), cor=F)
print(colour <- lmer(korr3 ~ cond3 + (1 | id), family=binomial, data=data[data$korr3!=-1,]), cor=F)


### LMM
print(shape2 <- lmer(korr1 ~ cond1 + (1 | id), data=data[data$korr1!=-1,]), cor = F)
print(texture2 <- lmer(korr2 ~ cond2 + (1 | id), data=data[data$korr2!=-1,]), cor = F)
print(colour2 <- lmer(korr3 ~ cond3 + (1 | id), data=data[data$korr3!=-1,]), cor = F)

# Same results as GLMM with advantage that coefficients estimate accuracy differences in prob metric

####################################################################
### Graphics
### shape 
# Aggregate to Subject x Cond  cells
data.id <- cast(data[data$korr1!=-1,], value="korr1", id + Bedingung + Cond1  ~ ., function(x) c(PC=mean(x), N=length(x)) )

### Removing Between-Subject Variance for errorbars 
  
GM <- mean(data.id$PC)
data.id <- ddply(data.id, .(id), transform, PC.w = PC - mean(PC) + GM)  
# checks
mean(data.id$PC); mean(data.id$PC.w); sd(data.id$PC); sd(data.id$PC.w)
# means
# Experimental vs. control
cast(data.id, value="PC", Bedingung ~ ., function(x) c(M=round(mean(x),2)))
# all probe- types
cast(data.id, value="PC", Cond1 ~ Bedingung, function(x) c(M=round(mean(x),2)))

########################################################################
###  Graphics  
# Means, standard deviation, n of observations per cell, standard error
(M1 <- cast(data.id, value="PC.w", Bedingung + Cond1 ~ . , 
	        function(x) c(PC = mean(x), 
	                     SD = sd(x), 
	                      N = length(x), 
	                     SE = signif(sd(x)/sqrt(length(x)), 2) ) ))
names(M1)[1] <- "Condition"
levels(M1$Condition) <- c("control", "experimental")
M1$Cond1 <- factor(M1$Cond1)
levels(M1$Cond1) <- c("non-repeated\nshape", "repeated\nshape")

#Plot
(p1 <- qplot(data=M1, x=Cond1, y=PC, shape=Condition, group=Condition,  
      xlab="Recall Shape", ylab="Proportion Correct", ylim = c(0.40,0.65), geom=c("point", "line") ) +
      scale_linetype_discrete("Condition") +
	theme_bw()+
      geom_errorbar(aes(max = PC + 1*SE, min = PC - 1*SE), width=.1) +  geom_point(size=3) )
###########################
### textures
# Aggregate to Subject x Cond  cells 
data.id <- cast(data[data$korr2!=-1,], value="korr2", id + Bedingung + Cond2  ~ ., function(x) c(PC=mean(x), N=length(x)) )

# Removing Between-Subject Variance for error bars 
GM <- mean(data.id$PC)
data.id <- ddply(data.id, .(id), transform, PC.w = PC - mean(PC) + GM)  
# checks
mean(data.id$PC); mean(data.id$PC.w); sd(data.id$PC); sd(data.id$PC.w)
# means
# Experimental vs. control
cast(data.id, value="PC", Bedingung ~ ., function(x) c(M=round(mean(x),2)))
# alle Probe- Typen
cast(data.id, value="PC", Cond2 ~ Bedingung, function(x) c(M=round(mean(x),2)))

###########################################################################
###  Graphics  
# Means, standard deviation, n of observations per cell, standard error
(M1 <- cast(data.id, value="PC.w", Bedingung + Cond2 ~ . , 
	        function(x) c(PC = mean(x), 
	                     SD = sd(x), 
	                      N = length(x), 
	                     SE = signif(sd(x)/sqrt(length(x)), 2) ) ))
names(M1)[1] <- "Condition"
levels(M1$Condition) <- c("control", "experimental")
M1$Cond2 <- factor(M1$Cond2)
levels(M1$Cond2) <- c("non-repeated\ntexture", "repeated\ntexture")

#Plot
(p2 <- qplot(data=M1, x=Cond2, y=PC, shape=Condition, group=Condition,  
      xlab="Recall Texture", ylab="Proportion Correct", ylim = c(0.40,0.65), geom=c("point", "line") ) +
      scale_linetype_discrete("Condition") +
      theme_bw()+
	geom_errorbar(aes(max = PC + 1*SE, min = PC - 1*SE), width=.1) +  geom_point(size=3) )
###########################
### colour
# Aggregate to Subject x Cond  cells
data.id <- cast(data[data$korr3!=-1,], value="korr3", id + Bedingung + Cond3  ~ ., function(x) c(PC=mean(x), N=length(x)) )

# Removing Between-Subject Variance for error bars 
GM <- mean(data.id$PC)
data.id <- ddply(data.id, .(id), transform, PC.w = PC - mean(PC) + GM)  
# checks
mean(data.id$PC); mean(data.id$PC.w); sd(data.id$PC); sd(data.id$PC.w)
# means
# Experimental vs. control
cast(data.id, value="PC", Bedingung ~ ., function(x) c(M=round(mean(x),2)))
# alle Probe- Typen
cast(data.id, value="PC", Cond3 ~ Bedingung, function(x) c(M=round(mean(x),2)))

##############################################################################
###  Graphics
# Means, standard deviation, n of observations per cell, standard error
(M1 <- cast(data.id, value="PC.w", Bedingung + Cond3 ~ . , 
	        function(x) c(PC = mean(x), 
	                     SD = sd(x), 
	                      N = length(x), 
	                     SE = signif(sd(x)/sqrt(length(x)), 2) ) ))
names(M1)[1] <- "Condition"
levels(M1$Condition) <- c("control", "experimental")
M1$Cond3 <- factor(M1$Cond3)
levels(M1$Cond3) <- c("non-repeated\ncolour", "repeated\ncolour")

#Plot
(p3 <- qplot(data=M1, x=Cond3, y=PC, shape=Condition, group=Condition,  
      xlab="Recall Colour", ylab="Proportion Correct", ylim = c(0.40,0.65), geom=c("point", "line") ) +
      scale_linetype_discrete("Condition") +
      theme_bw()+
	geom_errorbar(aes(max = PC + 1*SE, min = PC - 1*SE), width=.1) +  geom_point(size=3) )

###############################################################################################
## all data together  
#####################################################################################
# Which features were chosen? list feature = 1 = non-repeated from list, 2 = repeated from list, 0 = not part of the list
# shape
data$Listenmerkmal1[	data$Ort1==data$I1Form|data$Ort1==data$I2Form|data$Ort1==data$I3Form|data$Ort1==data$I4Form]<-1
data$Listenmerkmal1[	data$Ort1==data$I1Form&data$Ort1==data$I2Form|data$Ort1==data$I1Form&data$Ort1==data$I3Form|data$Ort1==data$I1Form&data$Ort1==data$I4Form|
				data$Ort1==data$I2Form&data$Ort1==data$I3Form|data$Ort1==data$I2Form&data$Ort1==data$I4Form|
				data$Ort1==data$I3Form&data$Ort1==data$I4Form]<-2
data$Listenmerkmal1[is.na(data$Listenmerkmal1)==TRUE]<-0
# texture
data$Listenmerkmal2[	data$Ort2==data$I1Muster|data$Ort2==data$I2Muster|data$Ort2==data$I3Muster|data$Ort2==data$I4Muster]<-1
data$Listenmerkmal2[	data$Ort2==data$I1Muster&data$Ort2==data$I2Muster|data$Ort2==data$I1Muster&data$Ort2==data$I3Muster|data$Ort2==data$I1Muster&data$Ort2==data$I4Muster|
				data$Ort2==data$I2Muster&data$Ort2==data$I3Muster|data$Ort2==data$I2Muster&data$Ort2==data$I4Muster|
				data$Ort2==data$I3Muster&data$Ort2==data$I4Muster]<-2
data$Listenmerkmal2[is.na(data$Listenmerkmal2)==TRUE]<-0
# colour
data$Listenmerkmal3[	data$Ort3==data$I1Farbe|data$Ort3==data$I2Farbe|data$Ort3==data$I3Farbe|data$Ort3==data$I4Farbe]<-1
data$Listenmerkmal3[	data$Ort3==data$I1Farbe&data$Ort3==data$I2Farbe|data$Ort3==data$I1Farbe&data$Ort3==data$I3Farbe|data$Ort3==data$I1Farbe&data$Ort3==data$I4Farbe|
				data$Ort3==data$I2Farbe&data$Ort3==data$I3Farbe|data$Ort3==data$I2Farbe&data$Ort3==data$I4Farbe|
				data$Ort3==data$I3Farbe&data$Ort3==data$I4Farbe]<-2
data$Listenmerkmal3[is.na(data$Listenmerkmal3)==TRUE]<-0

data1<-data[data$korr1!=-1,]
data2<-data[data$korr2!=-1,]
data3<-data[data$korr3!=-1,]
dim(data1)

data0<-rbind(data1,data2,data3)
dim(data0)
data0$korr<-c(1:7488)
#shape
data0$korr[1:2496]<-data1$korr1
#texture
data0$korr[2497:4992]<-data2$korr2
#colour
data0$korr[4993:7488]<-data3$korr3

#shape
data0$Cond[1:2496]<-data1$Cond1
#texture
data0$Cond[2497:4992]<-data2$Cond2
#colour
data0$Cond[4993:7488]<-data3$Cond3

#shape
data0$cond[1:2496]<-data1$cond1
#texture
data0$cond[2497:4992]<-data2$cond2
#colour
data0$cond[4993:7488]<-data3$cond3

#shape
data0$feature[1:2496]<-1 #shape
#texture
data0$feature[2497:4992]<-2 #texture
#colour
data0$feature[4993:7488]<-3 #colour

# difference chance level repeated (2/4) vs. non-repeated (1/4)
a<-mean(data0$korr[data0$cond==3])
b<-mean(data0$korr[data0$cond!=3])

b+ b/4
a-a/4

#############################################################################
### Do people prefer list features? (chance = 3/6 oder 4/6) or not p = 2/6

#shape
data0$Listenmerkmal[1:2496]<-data1$Listenmerkmal1
#texture
data0$Listenmerkmal[2497:4992]<-data2$Listenmerkmal2
#colour
data0$Listenmerkmal[4993:7488]<-data3$Listenmerkmal3

dim(data0)
sum(data0$Listenmerkmal==2)
sum(data0$Listenmerkmal==1)

# probability to choose feature that was not in the list
sum(data0$Listenmerkmal==0)/length(data0$Listenmerkmal)
# chance
2/6
# probability to choose list feature 
# Control
sum(data0$Bed==1&data0$Listenmerkmal==1)/length(data0$Listenmerkmal[data0$Bed==1])
# chance
4/6
# Experimental
sum(data0$Bed==2&(data0$Listenmerkmal==1|data0$Listenmerkmal==2))/length(data0$Listenmerkmal[data0$Bed==2])
# chance
3/6
# Experimental non-repeated
sum(data0$Bed==2&data0$Listenmerkmal==1)/length(data0$Listenmerkmal[data0$Bed==2])
# chance
1/4
# Experimental repeated
sum(data0$Bed==2&data0$Listenmerkmal==2)/length(data0$Listenmerkmal[data0$Bed==2])
# chance
2/4

# Test, if chance differs from real data:
# Control p(list feature, non-list feature)= (4/6,2/6)
chisq.test(c(3197,547),p=c(4/6,2/6))

# Experimental p(repeated,non-repeated,non-listfeature) = (1/6,2/6,3/6)
chisq.test(c(1690,1326,728),p=c(1/6,2/6,3/6))

# analyses of errors they made
sum(data0$Bed==2&data0$Listenmerkmal==0&data0$korr==0)
sum(data0$Bed==2&data0$Listenmerkmal==1&data0$korr==0)
sum(data0$Bed==2&data0$Listenmerkmal==2&data0$korr==0)

sum(data0$Bed==1&data0$Listenmerkmal==0&data0$korr==0)
sum(data0$Bed==1&data0$Listenmerkmal==1&data0$korr==0)

100/(1584+547)*547
100/(728+788+269)*269

# non-repeated cued
sum(data0$cond==2&data0$Listenmerkmal==1&data0$korr==0)#wrong non-repeated
sum(data0$cond==2&data0$Listenmerkmal==2&data0$korr==0)#wrong repeated
sum(data0$cond==2&data0$Listenmerkmal==0&data0$korr==0)#wrong 

100/(165+269+265)*165
1/6
100/(165+269+265)*269
1/6
100/(165+269+269)*265
3/6

# repeated cued
sum(data0$cond==3&data0$Listenmerkmal==1&data0$korr==0)#wrong non-repeated
sum(data0$cond==3&data0$Listenmerkmal==0&data0$korr==0)#wrong 
100/(623+463)*623
2/6
100/(623+463)*463
3/6

#Model
Daten<-as.data.frame(cbind(data0$Vpn[order(data0$Vpn)],data0$P_Ort[order(data0$Vpn)],data0$cond[order(data0$Vpn)],data0$korr[order(data0$Vpn)],data0$feature[order(data0$Vpn)]))
colnames(Daten)<-c("Vpn","P_Ort","cond","korr","feature")
Daten$P_Ort<-factor(Daten$P_Ort)
Daten$cond<-factor(Daten$cond)
Daten$Vpn<-factor(Daten$Vpn)
Daten$feature<-factor(Daten$feature)

#############################################################################
### all data
print(alle <- lmer(korr ~ cond + feature+(1 | Vpn), family=binomial, data=Daten), cor=F)
cmat <- matrix(c( -1,  1,  0,        # shape-texture
                  0,   1, -1), 3, 2) # texture-colour
cmat.inv <- fractions(ginv(t(cmat)))
contrasts(Daten$feature) <- cmat.inv
print(alle <- lmer(korr ~ feature+(1 | Vpn), family=binomial, data=Daten), cor=F)
print(alle <- lmer(korr ~ feature+(1 | Vpn), family=binomial, data=Daten), cor=F)

cmat <- matrix(c( 1,  -1,  0,        # C- E non-repeated
                0.5,0.5 , -1), 3, 2) # C- E repeated
 
cmat.inv <- fractions(ginv(t(cmat)))
contrasts(Daten$cond) <- cmat.inv
print(alle <- lmer(korr ~ cond+(1 | Vpn), family=binomial, data=Daten), cor=F)

##############################################################################
# means 
data.id <- cast(Daten, value="korr", Vpn + cond+ feature  ~ ., function(x) c(PC=mean(x), N=length(x)) )

# Removing Between-Subject Variance for error bars 
GM <- mean(data.id$PC)
data.id <- ddply(data.id, .(Vpn), transform, PC.w = PC - mean(PC) + GM)  
# checks
mean(data.id$PC); mean(data.id$PC.w); sd(data.id$PC); sd(data.id$PC.w)
# Mittelwerte
cast(data.id, value="PC", feature ~ ., function(x) c(M=round(mean(x),2)))
# alle Probe- Typen
cast(data.id, value="PC", cond ~ feature, function(x) c(M=round(mean(x),2)))

##########################################################################################
## position effects
#######################################################################################
print(alle <- lmer(korr ~ P_Ort + cond+(1 | Vpn), family=binomial, data=Daten), cor=F)

data0.id <- cast(data0, value="korr", Vpn + cond+ P_Ort  ~ ., function(x) c(PC=mean(x), N=length(x)) )

################# Removing Between-Subject Variance for error bars###################################
GM <- mean(data0.id$PC)
data0.id <- ddply(data0.id, .(Vpn), transform, PC.w = PC - mean(PC) + GM)  
# checks
mean(data0.id$PC); mean(data0.id$PC.w); sd(data0.id$PC); sd(data0.id$PC.w)
# means
cast(data0.id, value="PC", P_Ort ~ ., function(x) c(M=round(mean(x),2)))
cast(data0.id, value="PC", cond ~ ., function(x) c(M=round(mean(x),2)))

# all probe types
cast(data0.id, value="PC", cond ~ P_Ort, function(x) c(M=round(mean(x),2)))

#################################################################
###  Graphics
# Means, standard deviation, n of observations per cell, standard error
(M4 <- cast(data0.id, value="PC.w", cond + P_Ort ~ . , 
	        function(x) c(PC = mean(x), 
	                     SD = sd(x), 
	                      N = length(x), 
	                     SE = signif(sd(x)/sqrt(length(x)), 2) ) ))
M4$cond <- factor(M4$cond)
M4$Condition<-M4$cond
levels(M4$Condition) <- c("control\nnon-repeated\n","experimental\nnon-repeated\n","experimental\nrepeated\n")

M4$P_Ort <- factor(M4$P_Ort)
levels(M4$P_Ort) <- c("position1", "position2", "position3", "position4")

# Plot
(p4 <- qplot(data=M4[], x=P_Ort, y=PC, shape=Condition, group=Condition,  
      xlab="Position", ylab="Proportion Correct",ylim = c(0.20,0.80), geom=c("point", "line") ) +
      scale_linetype_discrete("Condition") +
      theme_bw()+
	geom_errorbar(aes(max = PC + 1*SE, min = PC - 1*SE), width=.1) +  geom_point(size=3) )
#############################################################
# Its over now.
#############################################################